==> kdesdk_4.8.5.orig.tar.xz: kdesdk-4.8.5/okteta/libs/kasten/controllers/view/select/selectcontroller.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SELECTCONTROLLER_H
#define SELECTCONTROLLER_H

// lib
#include "kastencontrollers_export.h"
// Kasten gui
#include <abstractxmlguicontroller.h>

class KXMLGUIClient;
class KAction;


namespace Kasten1
{

namespace If {
class DataSelectable;
}


class KASTENCONTROLLERS_EXPORT SelectController : public AbstractXmlGuiController
{
  Q_OBJECT

  public:
    explicit SelectController( KXMLGUIClient* guiClient );

  public: // AbstractXmlGuiController API
    virtual void setTargetModel( AbstractModel* model );

  protected Q_SLOTS: // action slots
    void selectAll();
    void unselect();

  private Q_SLOTS:
    void onHasSelectedDataChanged( bool hasSelectedData );

  protected:
    AbstractModel* mModel;
    If::DataSelectable* mSelectControl;

    KAction *mSelectAllAction;
    KAction *mDeselectAction;
};

}

#endif

==> kdesdk-4.10.5.tar.xz: kdesdk-4.10.5/okteta/libs/kasten/controllers/view/select/selectcontroller.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SELECTCONTROLLER_H
#define SELECTCONTROLLER_H

// lib
#include "kastencontrollers_export.h"
// Kasten gui
#include <abstractxmlguicontroller.h>

class KXMLGUIClient;
class KAction;


namespace Kasten2
{

namespace If {
class DataSelectable;
}


class KASTENCONTROLLERS_EXPORT SelectController : public AbstractXmlGuiController
{
  Q_OBJECT

  public:
    explicit SelectController( KXMLGUIClient* guiClient );

  public: // AbstractXmlGuiController API
    virtual void setTargetModel( AbstractModel* model );

  private Q_SLOTS: // action slots
    void selectAll();
    void unselect();

  private Q_SLOTS:
    void onHasSelectedDataChanged( bool hasSelectedData );

  private:
    AbstractModel* mModel;
    If::DataSelectable* mSelectControl;

    KAction *mSelectAllAction;
    KAction *mDeselectAction;
};

}

#endif
